@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Any, Dict, List, Union
+from typing import IO, Any, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
 
@@ -27,6 +27,7 @@ from .literals import (
     FaceAttributesType,
     FaceSearchSortByType,
     GenderTypeType,
+    KnownGenderTypeType,
     LabelDetectionSortByType,
     LandmarkTypeType,
     OrientationCorrectionType,
@@ -40,6 +41,7 @@ from .literals import (
     StreamProcessorStatusType,
     TechnicalCueTypeType,
     TextTypesType,
+    VideoColorRangeType,
     VideoJobStatusType,
 )
 
@@ -54,6 +56,7 @@ __all__ = (
     "AssetTypeDef",
     "AudioMetadataTypeDef",
     "BeardTypeDef",
+    "BlackFrameTypeDef",
     "BoundingBoxTypeDef",
     "CelebrityDetailTypeDef",
     "CelebrityRecognitionTypeDef",
@@ -147,6 +150,7 @@ __all__ = (
     "InstanceTypeDef",
     "KinesisDataStreamTypeDef",
     "KinesisVideoStreamTypeDef",
+    "KnownGenderTypeDef",
     "LabelDetectionTypeDef",
     "LabelTypeDef",
     "LandmarkTypeDef",
@@ -274,6 +278,15 @@ BeardTypeDef = TypedDict(
     total=False,
 )
 
+BlackFrameTypeDef = TypedDict(
+    "BlackFrameTypeDef",
+    {
+        "MaxPixelThreshold": float,
+        "MinCoveragePercentage": float,
+    },
+    total=False,
+)
+
 BoundingBoxTypeDef = TypedDict(
     "BoundingBoxTypeDef",
     {
@@ -315,6 +328,7 @@ CelebrityTypeDef = TypedDict(
         "Id": str,
         "Face": "ComparedFaceTypeDef",
         "MatchConfidence": float,
+        "KnownGender": "KnownGenderTypeDef",
     },
     total=False,
 )
@@ -371,6 +385,8 @@ ComparedFaceTypeDef = TypedDict(
         "Landmarks": List["LandmarkTypeDef"],
         "Pose": "PoseTypeDef",
         "Quality": "ImageQualityTypeDef",
+        "Emotions": List["EmotionTypeDef"],
+        "Smile": "SmileTypeDef",
     },
     total=False,
 )
@@ -411,7 +427,7 @@ _RequiredCreateCollectionRequestRequestTypeDef = TypedDict(
 _OptionalCreateCollectionRequestRequestTypeDef = TypedDict(
     "_OptionalCreateCollectionRequestRequestTypeDef",
     {
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -461,7 +477,7 @@ _RequiredCreateProjectVersionRequestRequestTypeDef = TypedDict(
 _OptionalCreateProjectVersionRequestRequestTypeDef = TypedDict(
     "_OptionalCreateProjectVersionRequestRequestTypeDef",
     {
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
         "KmsKeyId": str,
     },
     total=False,
@@ -496,7 +512,7 @@ _RequiredCreateStreamProcessorRequestRequestTypeDef = TypedDict(
 _OptionalCreateStreamProcessorRequestRequestTypeDef = TypedDict(
     "_OptionalCreateStreamProcessorRequestRequestTypeDef",
     {
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -546,7 +562,7 @@ DeleteFacesRequestRequestTypeDef = TypedDict(
     "DeleteFacesRequestRequestTypeDef",
     {
         "CollectionId": str,
-        "FaceIds": List[str],
+        "FaceIds": Sequence[str],
     },
 )
 
@@ -622,7 +638,7 @@ _RequiredDescribeProjectVersionsRequestRequestTypeDef = TypedDict(
 _OptionalDescribeProjectVersionsRequestRequestTypeDef = TypedDict(
     "_OptionalDescribeProjectVersionsRequestRequestTypeDef",
     {
-        "VersionNames": List[str],
+        "VersionNames": Sequence[str],
         "NextToken": str,
         "MaxResults": int,
     },
@@ -729,7 +745,7 @@ _RequiredDetectFacesRequestRequestTypeDef = TypedDict(
 _OptionalDetectFacesRequestRequestTypeDef = TypedDict(
     "_OptionalDetectFacesRequestRequestTypeDef",
     {
-        "Attributes": List[AttributeType],
+        "Attributes": Sequence[AttributeType],
     },
     total=False,
 )
@@ -851,7 +867,7 @@ DetectTextFiltersTypeDef = TypedDict(
     "DetectTextFiltersTypeDef",
     {
         "WordFilter": "DetectionFilterTypeDef",
-        "RegionsOfInterest": List["RegionOfInterestTypeDef"],
+        "RegionsOfInterest": Sequence["RegionOfInterestTypeDef"],
     },
     total=False,
 )
@@ -1043,6 +1059,7 @@ GetCelebrityInfoResponseTypeDef = TypedDict(
     {
         "Urls": List[str],
         "Name": str,
+        "KnownGender": "KnownGenderTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -1373,7 +1390,7 @@ class HumanLoopConfigTypeDef(_RequiredHumanLoopConfigTypeDef, _OptionalHumanLoop
 HumanLoopDataAttributesTypeDef = TypedDict(
     "HumanLoopDataAttributesTypeDef",
     {
-        "ContentClassifiers": List[ContentClassifierType],
+        "ContentClassifiers": Sequence[ContentClassifierType],
     },
     total=False,
 )
@@ -1407,7 +1424,7 @@ _OptionalIndexFacesRequestRequestTypeDef = TypedDict(
     "_OptionalIndexFacesRequestRequestTypeDef",
     {
         "ExternalImageId": str,
-        "DetectionAttributes": List[AttributeType],
+        "DetectionAttributes": Sequence[AttributeType],
         "MaxFaces": int,
         "QualityFilter": QualityFilterType,
     },
@@ -1457,6 +1474,14 @@ KinesisVideoStreamTypeDef = TypedDict(
     total=False,
 )
 
+KnownGenderTypeDef = TypedDict(
+    "KnownGenderTypeDef",
+    {
+        "Type": KnownGenderTypeType,
+    },
+    total=False,
+)
+
 LabelDetectionTypeDef = TypedDict(
     "LabelDetectionTypeDef",
     {
@@ -1737,7 +1762,7 @@ ProtectiveEquipmentSummarizationAttributesTypeDef = TypedDict(
     "ProtectiveEquipmentSummarizationAttributesTypeDef",
     {
         "MinConfidence": float,
-        "RequiredEquipmentTypes": List[ProtectiveEquipmentTypeType],
+        "RequiredEquipmentTypes": Sequence[ProtectiveEquipmentTypeType],
     },
 )
 
@@ -1878,6 +1903,9 @@ SegmentDetectionTypeDef = TypedDict(
         "DurationSMPTE": str,
         "TechnicalCueSegment": "TechnicalCueSegmentTypeDef",
         "ShotSegment": "ShotSegmentTypeDef",
+        "StartFrameNumber": int,
+        "EndFrameNumber": int,
+        "DurationFrames": int,
     },
     total=False,
 )
@@ -2134,7 +2162,7 @@ _RequiredStartSegmentDetectionRequestRequestTypeDef = TypedDict(
     "_RequiredStartSegmentDetectionRequestRequestTypeDef",
     {
         "Video": "VideoTypeDef",
-        "SegmentTypes": List[SegmentTypeType],
+        "SegmentTypes": Sequence[SegmentTypeType],
     },
 )
 _OptionalStartSegmentDetectionRequestRequestTypeDef = TypedDict(
@@ -2183,6 +2211,7 @@ StartTechnicalCueDetectionFilterTypeDef = TypedDict(
     "StartTechnicalCueDetectionFilterTypeDef",
     {
         "MinSegmentConfidence": float,
+        "BlackFrame": "BlackFrameTypeDef",
     },
     total=False,
 )
@@ -2191,7 +2220,7 @@ StartTextDetectionFiltersTypeDef = TypedDict(
     "StartTextDetectionFiltersTypeDef",
     {
         "WordFilter": "DetectionFilterTypeDef",
-        "RegionsOfInterest": List["RegionOfInterestTypeDef"],
+        "RegionsOfInterest": Sequence["RegionOfInterestTypeDef"],
     },
     total=False,
 )
@@ -2305,7 +2334,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
 )
 
@@ -2331,7 +2360,7 @@ TestingDataResultTypeDef = TypedDict(
 TestingDataTypeDef = TypedDict(
     "TestingDataTypeDef",
     {
-        "Assets": List["AssetTypeDef"],
+        "Assets": Sequence["AssetTypeDef"],
         "AutoCreate": bool,
     },
     total=False,
@@ -2372,7 +2401,7 @@ TrainingDataResultTypeDef = TypedDict(
 TrainingDataTypeDef = TypedDict(
     "TrainingDataTypeDef",
     {
-        "Assets": List["AssetTypeDef"],
+        "Assets": Sequence["AssetTypeDef"],
     },
     total=False,
 )
@@ -2390,7 +2419,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -2411,6 +2440,7 @@ VideoMetadataTypeDef = TypedDict(
         "FrameRate": float,
         "FrameHeight": int,
         "FrameWidth": int,
+        "ColorRange": VideoColorRangeType,
     },
     total=False,
 )
